@@ -5,9 +5,10 @@ This module does not contain docstrings for the wrapped code, check Apple's
 documentation for details on how to use these functions and classes.
 """
 import sys
-import objc
-import CoreFoundation
 
+import CoreFoundation
+import Foundation._Foundation
+import objc
 from Foundation import _metadata
 from Foundation._inlines import _inline_list_
 
@@ -15,7 +16,6 @@ objc.addConvenienceForClass(
     "NSAttributedString", (("__len__", lambda self: self.length()),)
 )
 
-# XXX
 objc.addConvenienceForBasicMapping("NSMergeConflict", True)
 objc.addConvenienceForBasicMapping("NSUbiquitousKeyValueStore", False)
 objc.addConvenienceForBasicMapping("NSUserDefaults", False)
@@ -82,7 +82,6 @@ def _setup_conveniences():
         else:
             return value
 
-    # XXX: add more of the set interface
     objc.addConvenienceForClass(
         "NSHashTable",
         (
@@ -96,24 +95,9 @@ def _setup_conveniences():
         ),
     )
 
-    # XXX: These convenience wrappers don't work due to type issues
-    # def charset_contains(self, value):
-    #    try:
-    #        return self.characterIsMember_(value)
-    #    except ValueErorr:
-    #        # Wrong type
-    #        return False
-
-    # objc.addConvenienceForClass('NSCharacterSet', (
-    #    ('__len__',         lambda self: self.count()),
-    #    ('__contains__',    charset_contains),
-    # ))
-
-    # XXX: add full set interface (even if other value can only be a set)
-    # objc.addConvenienceForClass('NSMutableCharacterSet', (
-
-    # XXX: add __new__, __getitem__ and __iter__ as well
-    objc.addConvenienceForClass("NSIndexPath", (("__len__", lambda self: self.count()),))
+    objc.addConvenienceForClass(
+        "NSIndexPath", (("__len__", lambda self: self.count()),)
+    )
 
     if sys.maxsize > 2 ** 32:
         NSNotFound = 0x7FFFFFFFFFFFFFFF
@@ -152,7 +136,6 @@ def _setup_conveniences():
         except ValueError:
             return False
 
-    # XXX: Add __new__
     objc.addConvenienceForClass(
         "NSIndexSet",
         (
@@ -193,47 +176,37 @@ sys.modules["Foundation"] = mod = objc.ObjCLazyModule(
         "objc": objc,
         "YES": objc.YES,
         "NO": objc.NO,
-        "NSMaximumStringLength": sys.maxsize - 1,
         "__path__": __path__,
         "__loader__": globals().get("__loader__", None),
     },
     (CoreFoundation,),
 )
 
-import sys
 
 del sys.modules["Foundation._metadata"]
 
-import Foundation._Foundation
 
 for nm in dir(Foundation._Foundation):
     if nm.startswith("_"):
         continue
     setattr(mod, nm, getattr(Foundation._Foundation, nm))
 
-import objc
 
 mod.NSDecimal = objc.NSDecimal
 
-import Foundation._nsobject
-import Foundation._nsindexset
-
-
-import Foundation._functiondefines
+import Foundation._context  # isort:skip  # noqa: E402
+import Foundation._functiondefines  # isort:skip  # noqa: E402
+import Foundation._nsindexset  # isort:skip  # noqa: E402
+import Foundation._nsobject  # isort:skip  # noqa: E402
 
 for nm in dir(Foundation._functiondefines):
     setattr(mod, nm, getattr(Foundation._functiondefines, nm))
 
 
-# XXX: This is suboptimal, could calculate this in the metadata
-# generator.
-import sys
-
 mod.NSIntegerMax = sys.maxsize
 mod.NSIntegerMin = -sys.maxsize - 1
 mod.NSUIntegerMax = (sys.maxsize * 2) + 1
 
-import Foundation._context
 
 for nm in dir(Foundation._context):
     setattr(mod, nm, getattr(Foundation._context, nm))
